RadioCodeCalculator

Struct RadioCodeCalculator 

pub struct RadioCodeCalculator {
    pub api_url: String,
    /* private fields */
}
Radio Code Calculator API module

Fields

api_url: String

@var string default Radio Code Calculator API WebApi endpoint

Implementations

Source

impl RadioCodeCalculator

pub const DEFAULT_API_URL: &'static str = "https://www.pelock.com/api/radio-code-calculator/v1"

Default Radio Code Calculator API WebApi endpoint

pub fn new(api_key: Option<String>) -> Self

Initialize Radio Code Calculator API class

@param string|null api_key Activation key for the service (it cannot be empty!)

pub fn with_client(api_key: Option<String>, client: Client) -> Self

Construct with a custom reqwest::Client (timeouts, proxies, etc.).

pub async fn login(&self) -> Result<Value, RadioCodeCalculatorError>

Login to the service and get the information about the current license limits

@return RadioCodeCalculator A list with an error code, and an optional dictionary with the raw results (or null on error)

pub async fn calc<R: AsRadioModelName + ?Sized>( &self, radio_model: &R, radio_serial_number: &str, radio_extra_data: &str, ) -> Result<Value, RadioCodeCalculatorError>

Calculate the radio code for the selected radio model

@param RadioModel|string radio_model Radio model either as a RadioModel class or a string @param string radio_serial_number Radio serial number / pre code @param string radio_extra_data Optional extra data (for example - a supplier code) to generate the radio code @return array A list with an error code, and an optional dictionary with the raw results (or null)

pub async fn info<R: AsRadioModelName + ?Sized>( &self, radio_model: &R, ) -> Result<InfoResult, RadioCodeCalculatorError>

Get the information about the given radio calculator and its parameters (name, max. len & regex pattern)

@param RadioModel|string radio_model Radio model either as a RadioModel class or a string @return array A list with an error code, and an optional RadioModel create from the return values (or null)

pub async fn list(&self) -> Result<ListResult, RadioCodeCalculatorError>

List all the supported radio calculators and their parameters (name, max. len & regex pattern)

@return array A list with an error code, and an optional list of supported RadioModels (or null)

pub async fn post_request( &self, params_array: HashMap<String, String>, ) -> Result<Value, RadioCodeCalculatorError>

Send a POST request to the server & returns a Promise

@param {Array} params_array params_array An array with the parameters @param {decodedCallback} callback_ Funkcja callback wywolywana po zdekodowaniu danych @returns {Promise} An array with the POST request results (or default error)