RadioErrors

Struct RadioErrors 

pub struct RadioErrors;
Errors returned by the Radio Code Calculator API interface

Usage:

if (error === RadioErrors.SUCCESS) { … }

Implementations

Source

impl RadioErrors

pub const ERROR_CONNECTION: i32 = -1

@var int cannot connect to the Web API interface (network error)

pub const SUCCESS: i32 = 0

@var int successful request

pub const INVALID_INPUT: i32 = 1

@var int an error occurred while validating input data (invalid length, format etc.)

pub const INVALID_COMMAND: i32 = 2

@var int invalid Web API command (not supported)

pub const INVALID_RADIO_MODEL: i32 = 3

@var int radio model is not supported by the calculator

pub const INVALID_SERIAL_LENGTH: i32 = 4

@var int radio serial number is invalid (invalid format, not matching the expected regex pattern)

pub const INVALID_SERIAL_PATTERN: i32 = 5

@var int radio serial number doesn’t match the expected regular expression pattern

pub const INVALID_SERIAL_NOT_SUPPORTED: i32 = 6

@var int radio serial number is not supported by the selected calculator

pub const INVALID_EXTRA_LENGTH: i32 = 7

@var int extra data is invalid (invalid format, not matching the expected regex pattern)

pub const INVALID_EXTRA_PATTERN: i32 = 8

@var int extra data doesn’t match the expected regular expression pattern

pub const INVALID_LICENSE: i32 = 100

@var int license key is invalid or expired