RadioModel

Struct RadioModel 

pub struct RadioModel {
    pub name: String,
    pub serial_max_len: usize,
    pub extra_max_len: usize,
    pub default_programming_language: String,
    /* private fields */
}
RadioModel class used to calculate the radio code for specified car radio/navigation

Fields

name: String

@var string A single radio model with its parameters

serial_max_len: usize

@var int Required, valid length of the radio serial/seed number

extra_max_len: usize

@var int Length of the optional param for radio code generation

default_programming_language: String

@var string Default programming language used to determine the format of regular expression formats

Implementations

Source

impl RadioModel

pub fn regex_string_to_rule(regex_string: &str) -> Result<Regex, Error>

In JS you cannot pass the extra parameters for the RegExp in a single string This function splits the provided rule into Reg Exp rule & extra params (like case insensitive flag)

@return RegExp regular expression

pub fn serial_regex_pattern(&self) -> String

Return the regex pattern for the current programming language only

@return RegExp|string PCRE compatible regular expression or an empty string “”

pub fn extra_regex_pattern(&self) -> Option<String>

Extra field (if defined) regex pattern for the current programming language only or null

@return RegExp|null PCRE compatible regular expression or null if not required

pub fn new( name: impl Into<String>, serial_max_len: usize, serial_regex_pattern: Value, extra_max_len: usize, extra_regex_pattern: Option<Value>, ) -> Self

Initialize RadioModel class with the radio model name, serial & extra fields max. length and regex pattern

@param string name Radio model name @param int serial_max_len Max. serial length @param string|array serial_regex_pattern Serial number single regex pattern or a dictionary @param int extra_max_len Max. extra field length @param string|array|null extra_regex_pattern: Extra field single regex pattern or a dictionary

pub fn with_slash_patterns( name: impl Into<String>, serial_max_len: usize, serial_regex: &str, extra_max_len: usize, extra_regex: Option<&str>, ) -> Self

Convenience for static presets using a single JS-style slash regex string.

pub fn validate(&self, serial: &str, extra: Option<&str>) -> i32

Validate radio serial number and extra data (if provided), check their lenghts and regex patterns

@param string serial Radio serial number @param string|null extra: Extra data (optional) @return int one of the RadioErrors values