pub struct RadioErrors;Expand description
Errors returned by the Radio Code Calculator API interface
Usage:
if (error === RadioErrors.SUCCESS) { … }
Implementations
Sourceimpl RadioErrors
impl RadioErrors
Sourcepub const ERROR_CONNECTION: i32 = -1
pub const ERROR_CONNECTION: i32 = -1
@var int cannot connect to the Web API interface (network error)
Sourcepub const INVALID_INPUT: i32 = 1
pub const INVALID_INPUT: i32 = 1
@var int an error occurred while validating input data (invalid length, format etc.)
Sourcepub const INVALID_COMMAND: i32 = 2
pub const INVALID_COMMAND: i32 = 2
@var int invalid Web API command (not supported)
Sourcepub const INVALID_RADIO_MODEL: i32 = 3
pub const INVALID_RADIO_MODEL: i32 = 3
@var int radio model is not supported by the calculator
Sourcepub const INVALID_SERIAL_LENGTH: i32 = 4
pub const INVALID_SERIAL_LENGTH: i32 = 4
@var int radio serial number is invalid (invalid format, not matching the expected regex pattern)
Sourcepub const INVALID_SERIAL_PATTERN: i32 = 5
pub const INVALID_SERIAL_PATTERN: i32 = 5
@var int radio serial number doesn’t match the expected regular expression pattern
Sourcepub const INVALID_SERIAL_NOT_SUPPORTED: i32 = 6
pub const INVALID_SERIAL_NOT_SUPPORTED: i32 = 6
@var int radio serial number is not supported by the selected calculator
Sourcepub const INVALID_EXTRA_LENGTH: i32 = 7
pub const INVALID_EXTRA_LENGTH: i32 = 7
@var int extra data is invalid (invalid format, not matching the expected regex pattern)
Sourcepub const INVALID_EXTRA_PATTERN: i32 = 8
pub const INVALID_EXTRA_PATTERN: i32 = 8
@var int extra data doesn’t match the expected regular expression pattern
Sourcepub const INVALID_LICENSE: i32 = 100
pub const INVALID_LICENSE: i32 = 100
@var int license key is invalid or expired